# Generated by Django 3.2.12 on 2022-02-02 17:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('background_task', '0003_auto_20210410_1529'),
    ]

    operations = [
        migrations.AlterField(
            model_name='completedtask',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='task',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
